/*This file must be used with FLTK1.3 with cairo enabled
 * config.h is generated by fltk on your system
 * this class provide export to png, use by:
  Fl_Cairo_Window_Tx* cai_wnd;
  cai_wnd->export_png( "test.png");
*/
#ifndef FL_CAIRO_WINDOW_TX
#define FL_CAIRO_WINDOW_TX

#include "config.h"
#include <FL/Fl.H>
#include <FL/Fl_Double_Window.H>

class Fl_Cairo_Window_Tx : public Fl_Double_Window {
public:
	Fl_Cairo_Window_Tx(int w, int h, const char* T=0) : Fl_Double_Window(w,h,T),draw_cb_(0) {}
	Fl_Cairo_Window_Tx(int x, int y, int w, int h, const char* T=0) : Fl_Double_Window(x,y,w,h,T),draw_cb_(0) {}

protected:
	void draw() {
		Fl_Double_Window::draw();
		// manual method ? if yes explicitly get a cairo_context here
		if (!Fl::cairo_autolink_context()) 
			Fl::cairo_make_current(this); 
		if (draw_cb_) draw_cb_(this, Fl::cairo_cc());
	}

public:
	typedef void (*cairo_draw_cb) (Fl_Cairo_Window_Tx* self, cairo_t* def);
	void set_draw_cb(cairo_draw_cb  cb){draw_cb_=cb;}
	
	void export_png( const char* filename) {
		redraw();
		Fl::flush();
		cairo_surface_t* cai_suf = cairo_get_target( Fl::cairo_cc());
		cairo_status_t result = CAIRO_STATUS_NULL_POINTER;
		if ( cai_suf) {
			result = cairo_surface_write_to_png( cai_suf, filename);
		}
		switch (result) {
		case CAIRO_STATUS_SUCCESS:
			// "PNG file was written successfully\n"
		break;
		case CAIRO_STATUS_NO_MEMORY:
			Fl::error("memory could not be allocated for the operation\n");
		break;
		case CAIRO_STATUS_SURFACE_TYPE_MISMATCH:
			Fl::error("the surface does not have pixel contents\n");
		break;
		case CAIRO_STATUS_WRITE_ERROR:
			Fl::error("an I/O error occurs while attempting to write the file\n");
		break;
		default:
			Fl::error("the cairo_surface_t is a null pointer\n");
		break;
		}
	}
private:
	cairo_draw_cb draw_cb_;
};

#endif // FL_CAIRO_WINDOW_TX
